WebMcpSupportStatus enum

Why WebMCP is or is not available in the current environment.

Inheritance
Available extensions

Values

supported → const WebMcpSupportStatus

The current page can register WebMCP tools.

unsupportedPlatform → const WebMcpSupportStatus

The current Dart runtime is not a web browser.

insecureContext → const WebMcpSupportStatus

The page is not running in a secure context.

browserApiUnavailable → const WebMcpSupportStatus

The browser does not expose document.modelContext.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WebMcpSupportStatus>
A constant List of the values in this enum, in order of their declaration.