WebMcpSupport class final
A feature-detection result with a status and readable explanation.
Constructors
- WebMcpSupport(WebMcpSupportStatus status, String message)
-
Creates a support result.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSupported → bool
-
Whether WebMCP tools can be registered in the current environment.
no setter
- message → String
-
Human-readable explanation of status.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → WebMcpSupportStatus
-
Machine-readable support state.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited